// 
// Module: BinnedProxyResponse
// Author: Hassan Siddiqui
//
// Description: 
// Provides a proxy layer to any GenericResponse object.
// This later rebins the raw data to suit the rebin
// factor specified.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: BinnedProxyResponse.h,v 1.4 2000/09/21 15:34:34 hsiddiqu Exp $

#ifndef BinnedProxyResponse_H
#define BinnedProxyResponse_H

/* General */

/* SAS-specific */
#include "Tracer.h"

/* Local */
#include "GenericResponse.h"

/********************************
 *
 * class BinnedProxyResponse
 *
 * Provides a proxy layer to any GenericResponse object.
 * This later rebins the raw data to suit the rebin
 * factor specified.
 *
 *********************************/

class BinnedProxyResponse : public GenericResponse
{

public:

  /* Constructors */
  BinnedProxyResponse (GenericResponse * response,
		       unsigned binfactor,
		       unsigned offset,
		       unsigned firstchannel,
		       unsigned detchans);

  /* Destructors */
  ~BinnedProxyResponse();


  /** Channel range accessors */
  const unsigned int   firstChannel() const;
  const unsigned int   lastChannel() const;


  /** Response Accessors */
  unsigned int                 ebinFirstIndex() const;
  unsigned int                 numberOfEbins() const;
  const Bin ebins(unsigned int row) const;
  const vector<double>         responseVector ( unsigned int row ) const;
  const vector<double>         responseVector ( double energy ) const;

  /* Ebounds Accessor */
  const BinnedAxis * ebounds() const;

  unsigned int energyToPha( double energy ) const;

private:
  
  GenericResponse * _response;
  unsigned _binFactor;
  unsigned _offset;

  unsigned _firstChannel;
  unsigned _detchans;
  unsigned _lastChannel;

  BinnedAxis * _ebounds;
};

#endif




